parade.template.workspace.jupyter.kernels package
=================================================

Module contents
---------------

.. automodule:: parade.template.workspace.jupyter.kernels
    :members:
    :undoc-members:
    :show-inheritance:
